@@ -1,16 +1,12 @@
 #ifndef CPPUNITTEST_UNITTESTTOOLSUITE_H
 #define CPPUNITTEST_UNITTESTTOOLSUITE_H
 
+#include <cppunit/Portability.h>
 #include <string>
 
-namespace CppUnitTest
+inline std::string unitTestToolSuiteName()
 {
-
-  inline std::string unitTestToolSuiteName()
-  {
-    return "UnitTestTool";
-  }
-
+  return "UnitTestTool";
 }
 
-#endif // CPPUNITTEST_UNITTESTTOOLSUITE_H
\ No newline at end of file
+#endif // CPPUNITTEST_UNITTESTTOOLSUITE_H
